import 'package:flutter/material.dart';
import 'package:rothko_mobile/rothko.dart';
import 'package:rothko_mobile/rothko_system/utilities/colors.dart';

class BannerFilledButton extends StatelessWidget {
  final String? message, header, buttonText;
  final Color? messageColor,
      buttonColor,
      bannerColor,
      headerColor,
      buttonTextColor;
  final void Function()? onPressed;
  final double? width, msgFontSize;

  BannerFilledButton(
      {@required this.message,
      this.messageColor,
      this.header,
      this.buttonText,
      this.buttonColor,
      this.bannerColor,
      this.headerColor,
      this.buttonTextColor,
      this.onPressed,
      this.width,
      this.msgFontSize});
  @override
  Widget build(BuildContext context) {
    return Container(
      height: 120.0,
      width: width ?? MediaQuery.of(context).size.width * 0.9,
      decoration: BoxDecoration(
          borderRadius: BorderRadius.circular(8.0),
          color: bannerColor ?? kPrimaryLighten5),
      child: Padding(
        padding: EdgeInsets.all(16.0),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            Text(
              header ?? 'Email Address',
              style: TextStyle(
                  fontFamily: 'Proxima Nova',
                  fontSize: 16.0,
                  fontWeight: FontWeight.w600,
                  color: headerColor ?? kPrimaryBase),
            ),
            SizedBox(
              height: 8.0,
            ),
            Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              crossAxisAlignment: CrossAxisAlignment.end,
              children: [
                Container(
                  width: MediaQuery.of(context).size.width * 0.6,
                  child: Text(
                    message ??
                        'Your email address is now connected to a Company.'
                            '\nContact your Company to get you started on Bento.',
                    style: TextStyle(
                        color: messageColor ?? kPrimaryDarken4,
                        fontSize: msgFontSize ?? 10,
                        height: 1.5,
                        fontFamily: 'Proxima Nova'),
                  ),
                ),
                Container(
                  width: 69.0,
                  height: 32.0,
                  child: FlatButton(
                    color: buttonColor ?? kPrimaryBase,
                    shape: RoundedRectangleBorder(
                        borderRadius: BorderRadius.only(
                            topRight: Radius.circular(20),
                            bottomLeft: Radius.circular(20.0),
                            bottomRight: Radius.circular(20.0),
                            topLeft: Radius.circular(0.0))),
//
                    onPressed: onPressed,
                    child: Text(
                      buttonText ?? 'Button',
                      style: TextStyle(
                          color: kLightNeutralLighten5, fontSize: 10.0),
                    ),
                  ),
                )
              ],
            ),
          ],
        ),
      ),
    );
  }
}
