import 'package:flutter/material.dart';
import 'package:rothko_mobile/rothko_system/utilities/colors.dart';

class BannerDefault extends StatelessWidget {
  final String? message;
  final IconData? bannerIcon;
  final Color? iconColor, messageColor, bannerColor, trailingIconColor;
  bool? withTrailingIcon;
  final void Function()? onPressed;
  final double? width, msgFontSize;

  BannerDefault(
      {@required this.message,
      this.bannerIcon,
      this.iconColor,
      this.messageColor,
      this.bannerColor,
      this.trailingIconColor,
      this.width,
      this.onPressed,
      @required this.withTrailingIcon,
      this.msgFontSize});

  @override
  Widget build(BuildContext context) {
    return Container(
      height: 80.0,
      width: width ?? MediaQuery.of(context).size.width * 0.9,
      decoration: BoxDecoration(
        borderRadius: BorderRadius.circular(8.0),
        color: bannerColor ?? kPrimaryLighten5,
      ),
      child: Padding(
        padding: EdgeInsets.all(8.0),
        child: Row(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          crossAxisAlignment: CrossAxisAlignment.center,
          children: [
            Row(
              children: [
                Icon(
                  bannerIcon ?? Icons.check_circle,
                  size: 24.0,
                  color: iconColor ?? kPrimaryBase,
                ),
                SizedBox(
                  width: 16.0,
                ),
                Container(
                  width: MediaQuery.of(context).size.width * 0.6,
                  child: Text(
                    message ??
                        'Your email address is now connected to a Company.'
                            '\nContact your Company to get you started on Bento.',
                    style: TextStyle(
                        color: messageColor ?? kPrimaryDarken4,
                        fontSize: msgFontSize ?? 10,
                        height: 1.5,
                        fontFamily: 'Proxima Nova'),
                  ),
                ),
              ],
            ),
            Container(
              child: withTrailingIcon!
                  ? IconButton(
                      icon: Icon(
                        Icons.close,
                        color: trailingIconColor ?? kPrimaryBase,
                        size: 16.0,
                      ),
                      onPressed: onPressed ?? () => Navigator.pop(context))
                  : Container(),
            )
          ],
        ),
      ),
    );
  }
}
