import 'dart:async';
import 'package:flutter/material.dart';

class ButtonTap extends StatefulWidget {
  final Widget? child;
  final bool? disabled;
  final void Function()? onTap;
  ButtonTap({@required this.child, this.disabled = false, this.onTap});
  @override
  _ButtonTapState createState() => _ButtonTapState();
}

class _ButtonTapState extends State<ButtonTap>
    with SingleTickerProviderStateMixin {
  AnimationController? _animationController;
  Animation<double>? _scaleAnimation;
  Duration duration = const Duration(milliseconds: 80);
  double _opacity = 1;

  @override
  void initState() {
    super.initState();
    _animationController = AnimationController(vsync: this, duration: duration);
    _scaleAnimation =
        Tween<double>(begin: 1, end: 0.94).animate(_animationController!);
  }

  @override
  void dispose() {
    _animationController!.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return AnimatedOpacity(
      duration: duration,
      opacity: _opacity,
      child: ScaleTransition(
        scale: _scaleAnimation!,
        child: GestureDetector(
          onTap: widget.disabled!
              ? () {}
              : () {
                  _animationController!.forward();
                  setState(() {
                    _opacity = 0.5;
                  });
                  Timer(Duration(milliseconds: 90), () {
                    setState(() {
                      _opacity = 1;
                    });
                    _animationController!.reverse();
                    Timer(Duration(milliseconds: 90), () {
                      widget.onTap!();
                    });
                  });
                },
          child: widget.child,
        ),
      ),
    );
  }
}
