import 'package:flutter/material.dart';
import 'package:rothko_mobile/rothko.dart';
import 'package:rothko_mobile/rothko_system/utilities/colors.dart';

//Future<void> ShowDialogIcon(BuildContext context) async {
//  showDialog(
//      context: context,
//      barrierDismissible: true,
//      builder: (BuildContext context) {
//        return DialogWithIcon();
//      });
//}

class DialogWithIcon extends StatelessWidget {
  final String? message, header, buttonText;
  final Color? messageColor,
      buttonColor,
      bannerColor,
      iconColor,
      buttonTextColor;
  final bool? withCancelButton;
  final Button? button;

  final Function()? onTapAction, onCancel, onCloseModal;
  final IconData? dialogIcon;
  final double? width, msgFontSize, buttonWidth;

  DialogWithIcon(
      {this.message,
      this.onCloseModal,
      this.messageColor,
      this.header,
      this.onCancel,
      this.button,
      this.withCancelButton = true,
      this.buttonText,
      this.dialogIcon,
      this.iconColor,
      this.buttonColor,
      this.bannerColor,
      this.buttonTextColor,
      this.onTapAction,
      this.width,
      this.buttonWidth,
      this.msgFontSize});
  @override
  Widget build(BuildContext context) {
    return AlertDialog(
      insetPadding: EdgeInsets.zero,
      contentPadding: EdgeInsets.zero,
      clipBehavior: Clip.antiAliasWithSaveLayer,
      shape: RoundedRectangleBorder(
        borderRadius: BorderRadius.circular(4.0),
      ),
      backgroundColor: kLightNeutralLighten0,
      content: Container(
        height: 350.0,
        decoration: BoxDecoration(
            borderRadius: BorderRadius.circular(4.0), color: kPrimaryLighten0),
        width: MediaQuery.of(context).size.width * 0.9,
        child: Stack(
          children: [
            Positioned(
              right: 0.0,
              top: 0.0,
              child: IconButton(
                  onPressed: onCloseModal ?? () => Navigator.pop(context),
                  padding: EdgeInsets.zero,
                  icon: Icon(
                    Icons.close,
                    size: 16.0,
                    color: kDarkNeutralLighten5,
                  )),
            ),
            Positioned(
              top: 50.0,
              left: 32.0,
              child: Text(
                header ?? 'Header',
                style: TextStyle(
                    color: kDarkNeutralBase,
                    fontWeight: FontWeight.w700,
                    fontSize: 20.0,
                    fontFamily: 'Proxima Nova'),
              ),
            ),
            Positioned(
              top: 90.0,
              left: 32.0,
              right: 32.0,
              child: Column(
                children: [
                  Container(
                    height: 160.0,
                    width: MediaQuery.of(context).size.width * 0.8,
                    decoration: BoxDecoration(
                      borderRadius: BorderRadius.circular(8.0),
                      color: bannerColor ?? kPrimaryLighten5,
                    ),
                    child: Padding(
                      padding: EdgeInsets.all(16.0),
                      child: Row(
                        mainAxisAlignment: MainAxisAlignment.spaceBetween,
                        crossAxisAlignment: CrossAxisAlignment.center,
                        children: [
                          Icon(
                            dialogIcon ?? Icons.check_circle,
                            size: 48.0,
                            color: iconColor ?? kPrimaryBase,
                          ),
                          Container(
                            width: MediaQuery.of(context).size.width * 0.49,
                            child: Text(
                              message ??
                                  'Your request to enable Bento wallet has been received.'
                                      '\nA confirmation email has been sent to you.',
                              style: TextStyle(
                                  fontWeight: FontWeight.w600,
                                  color: messageColor ?? kPrimaryDarken4,
                                  fontSize: msgFontSize ?? 14,
                                  height: 1.5,
                                  fontFamily: 'Proxima Nova'),
                            ),
                          ),
                        ],
                      ),
                    ),
                  ),
                  SizedBox(
                    height: 24.0,
                  ),
                  Row(
                    mainAxisAlignment: MainAxisAlignment.end,
                    children: [
                      withCancelButton!
                          ? Container(
                              padding: EdgeInsets.all(8.0),
                              width: 80.0,
                              height: 32.0,
                              child: GestureDetector(
                                onTap: onCancel,
                                child: Text(
                                  'Cancel',
                                  style: TextStyle(
                                      fontWeight: FontWeight.w600,
                                      color: kDarkNeutralBase,
                                      fontSize: 14.0),
                                ),
                              ),
                            )
                          : Container(),
                      button ??
                          Button(
                              loading: false,
                              size: ButtonSize.NORMAL,
                              icon: '',
                              text: "Accept",
                              onPressed: onTapAction,
                              filled: false,
                              type: ButtonType.PRIMARY),
                    ],
                  )
                ],
              ),
            ),
          ],
        ),
      ),
    );
  }
}
