import 'package:flutter/material.dart';
import 'package:rothko_mobile/rothko.dart';
import 'package:rothko_mobile/rothko_system/utilities/colors.dart';

class DialogScrollable extends StatefulWidget {
  final String? header, buttonText;
  final Color? buttonColor, bannerColor, buttonTextColor;

  final TextEditingController? textEditingController;
  final Function()? onTapAction;
  final Function()? onCancel, onCloseModal;

  final double? msgFontSize;
  final Button? button;

  DialogScrollable(
      {this.header,
      this.button,
      this.buttonText,
      this.buttonColor,
      this.bannerColor,
      this.buttonTextColor,
      this.textEditingController,
      this.onTapAction,
      this.onCancel,
      this.onCloseModal,
      this.msgFontSize});

  @override
  _DialogScrollableState createState() => _DialogScrollableState();
}

class _DialogScrollableState extends State<DialogScrollable> {
  TextEditingController _textfieldController = TextEditingController();
  @override
  Widget build(BuildContext context) {
    return AlertDialog(
      insetPadding: EdgeInsets.zero,
      contentPadding: EdgeInsets.zero,
      clipBehavior: Clip.antiAliasWithSaveLayer,
      shape: RoundedRectangleBorder(
        borderRadius: BorderRadius.circular(4.0),
      ),
      backgroundColor: kLightNeutralLighten0,
      content: Container(
        height: 350,
        decoration: BoxDecoration(
            borderRadius: BorderRadius.circular(4.0), color: kPrimaryLighten0),
        width: MediaQuery.of(context).size.width * 0.9,
        child: Stack(
          children: [
            Positioned(
              right: 0.0,
              top: 0.0,
              child: IconButton(
                  onPressed:
                      widget.onCloseModal ?? () => Navigator.pop(context),
                  padding: EdgeInsets.zero,
                  icon: Icon(
                    Icons.close,
                    size: 16.0,
                    color: kDarkNeutralLighten5,
                  )),
            ),
            Positioned(
              top: 50.0,
              left: 32.0,
              child: Text(
                widget.header ?? 'Header',
                style: TextStyle(
                    color: kDarkNeutralBase,
                    fontWeight: FontWeight.w700,
                    fontSize: 20.0,
                    fontFamily: 'Proxima Nova'),
              ),
            ),
            Positioned(
              top: 90.0,
              left: 32.0,
              right: 32.0,
              child: Column(
                children: [
                  Container(
                    height: 160.0,
                    width: MediaQuery.of(context).size.width * 0.8,
                    decoration: BoxDecoration(
                        borderRadius: BorderRadius.circular(8.0),
                        color: widget.bannerColor ?? kPrimaryLighten5),
                    child: Padding(
                      padding: EdgeInsets.all(16.0),
                      child: Container(
                          width: MediaQuery.of(context).size.width * 0.6,
                          child: Scrollbar(
                            thickness: 6.0,
                            child: SingleChildScrollView(
                              scrollDirection: Axis.vertical,
                              reverse: true,
                              child: TextFormField(
                                maxLines: 6,
                                maxLengthEnforced: false,
                                cursorColor: kDarkNeutralBase,
                                controller: widget.textEditingController ??
                                    _textfieldController,
                                style: TextStyle(
                                  color: kDarkNeutralBase,
                                  fontSize: widget.msgFontSize ?? 16.0,
                                  fontFamily: 'Proxima Nova',
                                  height: 1.5,
                                ),
                                decoration: InputDecoration(
                                    border: OutlineInputBorder(
                                        borderSide: BorderSide.none)),
                              ),
                            ),
                          )),
                    ),
                  ),
                  SizedBox(
                    height: 24.0,
                  ),
                  Row(
                    mainAxisAlignment: MainAxisAlignment.end,
                    children: [
                      Container(
                        width: 80.0,
                        height: 32.0,
                        child: OutlineButton(
                          onPressed: widget.onCancel ?? () {},
                          child: Text(
                            'Cancel',
                            style: TextStyle(
                                fontWeight: FontWeight.w600,
                                color: kDarkNeutralBase,
                                fontSize: 14.0),
                          ),
                        ),
                      ),
                      SizedBox(
                        width: 16.0,
                      ),
                      widget.button ??
                          Button(
                              loading: false,
                              size: ButtonSize.NORMAL,
                              icon: '',
                              text: "Submit",
                              onPressed: widget.onTapAction,
                              filled: false,
                              type: ButtonType.PRIMARY),
                    ],
                  )
                ],
              ),
            ),
          ],
        ),
      ),
    );
  }
}
