import 'package:flutter/material.dart';
import 'package:intl/intl.dart';
import 'package:rothko_mobile/cache.dart';
import 'package:rothko_mobile/rothko_system/utilities/colors.dart';

class DatePicker extends StatefulWidget {
  final int? maxlength;
  final Widget? dateIcon;
  final double? width;
  bool? readOnly, enabled;
  final String? labelText;
  final String? hintText;
  final Function(DateTime? value)? onChanged;
  late DateTime? selectedValue;
  String? initialValue;
  final String? format;
  final String? Function(String?)? validator;
  final TextEditingController? dateController;

  DatePicker(
      {this.maxlength,
      this.dateIcon,
      this.width,
      this.labelText,
      this.enabled = true,
      this.initialValue,
      this.hintText,
      this.validator,
      this.onChanged,
      required this.dateController,
      this.format = 'yyyy-MM-dd',
      required this.selectedValue}) {
    if (this.selectedValue == null) {
      this.selectedValue = DateTime.now();
    }
  }

  @override
  _DatePickerState createState() => _DatePickerState();
}

const MaterialColor _datePickerColor = MaterialColor(0xFF0047CC, <int, Color>{
  50: Color(0xFF0047CC),
  100: Color(0xFF0047CC),
  200: Color(0xFF0047CC),
  300: Color(0xFF0047CC),
  400: Color(0xFF0047CC),
  500: Color(0xFF0047CC),
  600: Color(0xFF0047CC),
  700: Color(0xFF0047CC),
  800: Color(0xFF0047CC),
  900: Color(0xFF0047CC)
});

class _DatePickerState extends State<DatePicker> {
  DateTime selectedValue = DateTime.now();
  var currentValue = '';
  FocusNode? _labelFocusNode;
  bool isFocused = false;

  @override
  initState() {
    super.initState();

    if (widget.dateController != null) {
      currentValue = widget.dateController!.text;
    }
    if (widget.initialValue != null) {
      currentValue = widget.initialValue!;
    }
    selectedValue = widget.selectedValue!;
    _labelFocusNode = FocusNode();

    if (widget.initialValue != null) {
      widget.dateController?.text = widget.initialValue!;
    }
    _labelFocusNode!.addListener(() {
      if (_labelFocusNode!.hasFocus) {
        setState(() {
          isFocused = true;
        });
        return;
      }
      setState(() {
        isFocused = false;
      });
    });
  }

  @override
  void dispose() {
    _labelFocusNode!.dispose();
    super.dispose();
  }

  void _requestFocus() {
    setState(() {
      FocusScope.of(context).requestFocus(_labelFocusNode);
    });
  }

  Color fillColor = kLightNeutralLighten5;

  _selectDate() async {
    _requestFocus();
    final DateTime picked = (await showDatePicker(
      context: context,
      initialDate: selectedValue,
      // firstDate: DateTime(1900),
      firstDate: new DateTime(DateTime.now().year - 100),
      lastDate: new DateTime(DateTime.now().year + 100),
      builder: (BuildContext context, Widget? child) {
        return Theme(
          // data: ThemeData.dark(), // This will change to light theme.
          data: ThemeData(
            // primaryColor: Colors.amber,
            primarySwatch: _datePickerColor,
          ),
          child: child!,
        );
      },
    ))!;

    if (picked != null) {
      setState(() {
        selectedValue = picked;
        widget.dateController!.text = formatDate(picked);

        widget.onChanged!(picked);
      });
      setState(() {
        currentValue = formatDate(picked);
      });
    }
  }

  String formatDate(DateTime date) {
    return DateFormat(widget.format ?? 'yyyy-MM-dd').format(date);
  }

  @override
  Widget build(BuildContext context) {
    return Container(
        width: widget.width,
        child: Stack(
          children: <Widget>[
            TextFormField(
              initialValue: widget.initialValue,
              autovalidateMode: AutovalidateMode.onUserInteraction,
              validator: widget.validator,
              // initialValue: formatDate(selectedValue),
              controller: widget.dateController,
              maxLength: widget.maxlength,
              maxLengthEnforced: false,
              readOnly: true,

              cursorColor: RothkoCache.getTheme!(context) == ThemeMode.light
                  ? kDarkNeutralBase
                  : kLightNeutralBase,
              cursorHeight: 24.0,
              // focusNode: _labelFocusNode,
              onTap: () => _selectDate(),

              style: TextStyle(
                  height: _labelFocusNode!.hasFocus ? 1.0 : 1.5,
                  color: RothkoCache.getTheme!(context) == ThemeMode.light
                      ? kDarkNeutralBase
                      : kLightNeutralBase,
                  fontFamily: 'Proxima Nova',
                  fontSize: 16.0,
                  fontWeight: FontWeight.w400),
              decoration: InputDecoration(
                border: OutlineInputBorder(
                    borderRadius: BorderRadius.circular(8),
                    borderSide: BorderSide(
                        color: RothkoCache.getTheme!(context) == ThemeMode.light
                            ? kLightNeutralLighten1
                            : kDarkNeutralLighten2)),
                errorStyle: TextStyle(color: kErrorBase),
                errorBorder: OutlineInputBorder(
                    borderRadius: BorderRadius.circular(8),
                    borderSide: BorderSide(color: kErrorBase)),
                enabledBorder: OutlineInputBorder(
                    borderRadius: BorderRadius.circular(8),
                    borderSide: BorderSide(
                        style: BorderStyle.solid,
                        color: RothkoCache.getTheme!(context) == ThemeMode.light
                            ? kLightNeutralLighten1
                            : kLightNeutralLighten5)),
                focusedBorder: OutlineInputBorder(
                    borderRadius: BorderRadius.circular(8),
                    borderSide: BorderSide(
                        style: BorderStyle.solid,
                        color: RothkoCache.getTheme!(context) == ThemeMode.light
                            ? kLightNeutralLighten1
                            : Colors.red)),
                contentPadding: EdgeInsets.only(bottom: 16.0, left: 16.0),
                fillColor: RothkoCache.getTheme!(context) == ThemeMode.light &&
                        !_labelFocusNode!.hasFocus
                    ? kLightNeutralLighten5
                    : RothkoCache.getTheme!(context) == ThemeMode.light &&
                            _labelFocusNode!.hasFocus &&
                            widget.enabled!
                        ? kLightNeutralLighten4
                        : RothkoCache.getTheme!(context) == ThemeMode.dark &&
                                !_labelFocusNode!.hasFocus
                            ? kDarkNeutralBase
                            : kDarkNeutralLighten1,
                hintText: widget.hintText,
                filled: true,
                // helperText: widget.helperHint,
                helperStyle: TextStyle(
                    fontSize: 10.0,
                    color: kDarkNeutralLighten3,
                    fontFamily: 'Proxima Nova'),
                suffixIcon: Padding(
                  padding: const EdgeInsets.only(
                      top: 15, left: 5, right: 0, bottom: 15),
                  child: new SizedBox(
                    height: 4,
                    child: widget.dateIcon ??
                        Image.asset('assets/img/calendar-outline.png'),
                  ),
                ),

                labelStyle: TextStyle(
                    fontSize: _labelFocusNode!.hasFocus ? 10.0 : 10.0,
                    fontFamily: 'Proxima Nova',
                    color: RothkoCache.getTheme!(context) == ThemeMode.light &&
                            !_labelFocusNode!.hasFocus &&
                            widget.enabled!
                        ? kDarkNeutralBase
                        : RothkoCache.getTheme!(context) == ThemeMode.light &&
                                _labelFocusNode!.hasFocus &&
                                widget.enabled!
                            ? kDarkNeutralLighten3
                            : RothkoCache.getTheme!(context) ==
                                        ThemeMode.dark &&
                                    !_labelFocusNode!.hasFocus &&
                                    widget.enabled!
                                ? kLightNeutralBase
                                : kPrimaryLighten3),
              ),
            ),
            Positioned(
                left: 13,
                top: currentValue.isEmpty ? 17 : 2,
                child: Text(
                  isFocused ? '' : widget.labelText ?? 'Date',
                  style: TextStyle(
                      fontSize: currentValue.isEmpty ? 14 : 10,
                      fontFamily: 'Proxima Nova',
                      color: RothkoCache.getTheme!(context) ==
                                  ThemeMode.light &&
                              !_labelFocusNode!.hasFocus &&
                              widget.enabled!
                          ? kDarkNeutralLighten3
                          : RothkoCache.getTheme!(context) == ThemeMode.light &&
                                  _labelFocusNode!.hasFocus &&
                                  widget.enabled!
                              ? kDarkNeutralLighten3
                              : RothkoCache.getTheme!(context) ==
                                          ThemeMode.dark &&
                                      !_labelFocusNode!.hasFocus &&
                                      widget.enabled!
                                  ? kLightNeutralBase
                                  : kPrimaryLighten3),
                ))
          ],
        ));
  }
}
