import 'package:flutter/material.dart';
import 'package:intl/intl.dart';
import 'package:rothko_mobile/cache.dart';
import 'package:rothko_mobile/rothko_system/utilities/colors.dart';

class NewDatePicker extends StatefulWidget {
  final int? maxlength;
  final Icon? dateIcon;
  final double? width;
  final String? labelText;
  final Function(DateTime? value)? onChanged;
  late DateTime? selectedValue;
  final String? format;
  final String? Function(String?)? validator;
  TextEditingController? dateController;

  NewDatePicker(
      {this.maxlength,
      this.dateIcon,
      this.width,
      this.labelText,
      this.validator,
      this.onChanged,
      this.dateController,
      this.format = 'yyyy-MM-dd',
      required this.selectedValue}) {
    if (this.selectedValue == null) {
      this.selectedValue = DateTime.now();
    }
  }

  @override
  _NewDatePickerState createState() => _NewDatePickerState();
}

const MaterialColor _datePickerColor = MaterialColor(0xFF0047CC, <int, Color>{
  50: Color(0xFF0047CC),
  100: Color(0xFF0047CC),
  200: Color(0xFF0047CC),
  300: Color(0xFF0047CC),
  400: Color(0xFF0047CC),
  500: Color(0xFF0047CC),
  600: Color(0xFF0047CC),
  700: Color(0xFF0047CC),
  800: Color(0xFF0047CC),
  900: Color(0xFF0047CC)
});

class _NewDatePickerState extends State<NewDatePicker> {
  DateTime selectedValue = DateTime.now();

  var _textEditingController = TextEditingController();
  @override
  initState() {
    super.initState();

    selectedValue = widget.selectedValue!;
    _labelFocusNode = FocusNode();
    _textEditingController =
        TextEditingController(text: formatDate(selectedValue));
    widget.dateController =
        TextEditingController(text: formatDate(selectedValue));
  }

  @override
  void dispose() {
    _labelFocusNode.dispose();
    super.dispose();
  }

  void _requestFocus() {
    _labelFocusNode.requestFocus();

    _selectDate(context);
  }

  late FocusNode _labelFocusNode;
  Color fillColor = kLightNeutralLighten5;

  _selectDate(BuildContext context) async {
    final DateTime picked = (await showDatePicker(
      context: context,
      initialDate: selectedValue,
      // firstDate: DateTime(1900),
      firstDate: new DateTime(DateTime.now().year - 100),
      lastDate: new DateTime(DateTime.now().year + 100),
      builder: (BuildContext context, Widget? child) {
        return Theme(
          // data: ThemeData.dark(), // This will change to light theme.
          data: ThemeData(
            // primaryColor: Colors.amber,
            primarySwatch: _datePickerColor,
          ),
          child: child!,
        );
      },
    ))!;
    if (picked != null) {
      setState(() {
        selectedValue = picked;
      });
      _textEditingController.text = formatDate(picked);
      widget.dateController!.text = formatDate(picked);
      widget.onChanged!(picked);
    }
  }

  String formatDate(DateTime date) {
    return DateFormat(widget.format).format(date);
  }

  @override
  Widget build(BuildContext context) {
    return Container(
        width: widget.width,
        child: TextFormField(
          autovalidateMode: AutovalidateMode.onUserInteraction,
          validator: widget.validator,
          // initialValue: formatDate(selectedValue),
          controller: widget.dateController ?? _textEditingController,
          maxLength: widget.maxlength,
          maxLengthEnforced: false,
          readOnly: true,
          cursorColor: RothkoCache.getTheme!(context) == ThemeMode.light
              ? kDarkNeutralBase
              : kLightNeutralBase,
          cursorHeight: 24.0,
          // focusNode: _labelFocusNode,
          onTap: _requestFocus,
          style: TextStyle(
              height: _labelFocusNode.hasFocus ? 1.0 : 1.5,
              color: RothkoCache.getTheme!(context) == ThemeMode.light
                  ? kDarkNeutralBase
                  : kLightNeutralBase,
              fontFamily: 'Proxima Nova',
              fontSize: 16.0,
              fontWeight: FontWeight.w400),
          decoration: InputDecoration(
            suffixIcon: new Padding(
              padding: const EdgeInsets.only(
                  top: 15, left: 5, right: 0, bottom: 15),
              child: new SizedBox(
                height: 4,
                child: widget.dateIcon ??
                    Image.asset('assets/img/calendar-outline.png'),
              ),
            ),
            errorBorder: UnderlineInputBorder(
                borderSide: BorderSide(color: kErrorBase)),
            focusedBorder: OutlineInputBorder(
                borderRadius: BorderRadius.circular(8),
                borderSide: BorderSide(
                    color: RothkoCache.getTheme!(context) == ThemeMode.light
                        ? kLightNeutralLighten1
                        : kDarkNeutralLighten2)),
            contentPadding: EdgeInsets.only(bottom: 16.0, left: 16.0),
            fillColor: RothkoCache.getTheme!(context) == ThemeMode.light &&
                    !_labelFocusNode.hasFocus
                ? kLightNeutralLighten5
                : RothkoCache.getTheme!(context) == ThemeMode.light &&
                        _labelFocusNode.hasFocus
                    ? kLightNeutralLighten4
                    : RothkoCache.getTheme!(context) == ThemeMode.dark &&
                            !_labelFocusNode.hasFocus
                        ? kDarkNeutralBase
                        : kDarkNeutralLighten1,
            filled: true,
            // helperText: widget.helperHint,
            helperStyle: TextStyle(
                fontSize: 10.0,
                color: kDarkNeutralLighten3,
                fontFamily: 'Proxima Nova'),

            // hintText: widget.labelText ?? "Date",
            labelText: widget.labelText ?? "Date",
            labelStyle: TextStyle(
                height: _labelFocusNode.hasFocus ? 1.0 : 1.5,
                fontSize: 16.0,
                fontFamily: 'Proxima Nova',
                color: RothkoCache.getTheme!(context) == ThemeMode.light &&
                        !_labelFocusNode.hasFocus
                    ? kDarkNeutralBase
                    : RothkoCache.getTheme!(context) == ThemeMode.light &&
                            _labelFocusNode.hasFocus
                        ? kDarkNeutralLighten3
                        : RothkoCache.getTheme!(context) ==
                                    ThemeMode.dark &&
                                !_labelFocusNode.hasFocus
                            ? kLightNeutralBase
                            : kPrimaryLighten3),
            enabledBorder: OutlineInputBorder(
                borderRadius: BorderRadius.circular(8),
                borderSide: BorderSide(
                    color: RothkoCache.getTheme!(context) == ThemeMode.light
                        ? kLightNeutralLighten1
                        : kDarkNeutralLighten2)),
            border: OutlineInputBorder(
                borderRadius: BorderRadius.circular(8),
                borderSide: BorderSide(
                    color: RothkoCache.getTheme!(context) == ThemeMode.light
                        ? kLightNeutralLighten1
                        : kDarkNeutralLighten2)),
          ),
        ));
  }
}
