import 'package:flutter/material.dart';
import 'package:date_format/date_format.dart';
import 'package:rothko_mobile/cache.dart';
import 'package:rothko_mobile/rothko_system/utilities/colors.dart';

class TimePicker extends StatefulWidget {
  final int? maxlength;
  final Widget? timeIcon;
  final double? width;
  bool? readOnly, enabled;
  final String? labelText;
  final String? hintText;
  final Function(TimeOfDay? value)? onChanged;
  late DateTime? selectedValue;
  String? initialValue;
  final String? Function(String?)? validator;
  final TextEditingController? timeController;
  TimePicker({
    this.maxlength,
    this.timeIcon,
    this.width,
    this.labelText,
    this.enabled = true,
    this.initialValue,
    this.hintText,
    this.validator,
    this.selectedValue,
    this.onChanged,
    required this.timeController,
  });
  @override
  _TimePickerState createState() => _TimePickerState();
}

const MaterialColor _timePickerColor = MaterialColor(0xFF0047CC, <int, Color>{
  50: Color(0xFF0047CC),
  100: Color(0xFF0047CC),
  200: Color(0xFF0047CC),
  300: Color(0xFF0047CC),
  400: Color(0xFF0047CC),
  500: Color(0xFF0047CC),
  600: Color(0xFF0047CC),
  700: Color(0xFF0047CC),
  800: Color(0xFF0047CC),
  900: Color(0xFF0047CC)
});

class _TimePickerState extends State<TimePicker> {
  FocusNode? _labelFocusNode;
  bool isFocused = false;
  DateTime selectedValue = DateTime.now();

  @override
  initState() {
    super.initState();

    if (widget.timeController != null) {
      currentValue = widget.timeController!.text;
    }
    if (widget.initialValue != null) {
      currentValue = widget.initialValue!;
    }
    selectedValue = widget.selectedValue!;
    _labelFocusNode = FocusNode();

    if (widget.initialValue != null) {
      widget.timeController?.text = widget.initialValue!;
    }
    _labelFocusNode!.addListener(() {
      if (_labelFocusNode!.hasFocus) {
        setState(() {
          isFocused = true;
        });
        return;
      }
      setState(() {
        isFocused = false;
      });
    });
  }

  @override
  void dispose() {
    _labelFocusNode!.dispose();
    super.dispose();
  }

  void _requestFocus() {
    setState(() {
      FocusScope.of(context).requestFocus(_labelFocusNode);
    });
  }

  _selectTime(BuildContext context) async {
    _requestFocus();
    final TimeOfDay picked = (await showTimePicker(
      builder: (BuildContext context, Widget? child) {
        return Theme(
          // data: ThemeData.dark(), // This will change to light theme.
          data: ThemeData(
            primarySwatch: _timePickerColor,
          ),
          child: child!,
        );
      },
      context: context,
      initialTime: selectedTime,
    ))!;

    if (picked != null)
      setState(() {
        selectedTime = picked;

        widget.onChanged!(picked);
        _hour = selectedTime.hour.toString();
        _minute = selectedTime.minute.toString();
        _time = _hour! + ' : ' + _minute!;
        widget.timeController?.text = _time!;
        widget.timeController?.text = formatDate(
            DateTime(2019, 08, 1, selectedTime.hour, selectedTime.minute),
            [hh, ':', nn, " ", am]).toString();
      });
  }

  var currentValue = '';

  double? h;
  double? w;

  String? _hour, _minute, _time;

  String? dateTime;

  DateTime selectedDate = DateTime.now();

  TimeOfDay selectedTime = TimeOfDay(hour: 00, minute: 00);

  Color fillColor = kLightNeutralLighten5;

  @override
  Widget build(BuildContext context) {
    return Container(
        width: widget.width,
        child: Stack(
          children: [
            TextFormField(
              initialValue: widget.initialValue,
              maxLength: widget.maxlength,
              maxLengthEnforced: false,
              readOnly: true,
              controller: widget.timeController,
              cursorColor: RothkoCache.getTheme!(context) == ThemeMode.light
                  ? kDarkNeutralBase
                  : kLightNeutralBase,
              cursorHeight: 24.0,
              // focusNode: _labelFocusNode,
              onTap: () => _selectTime(context),
              style: TextStyle(
                  color: RothkoCache.getTheme!(context) == ThemeMode.light
                      ? kDarkNeutralBase
                      : kLightNeutralBase,
                  fontFamily: 'Proxima Nova',
                  fontSize: 16.0,
                  fontWeight: FontWeight.w400),
              decoration: InputDecoration(
                border: OutlineInputBorder(
                    borderRadius: BorderRadius.circular(8),
                    borderSide: BorderSide(
                        color: RothkoCache.getTheme!(context) == ThemeMode.light
                            ? kLightNeutralLighten1
                            : kDarkNeutralLighten2)),
                errorStyle: TextStyle(color: kErrorBase),
                errorBorder: OutlineInputBorder(
                    borderRadius: BorderRadius.circular(8),
                    borderSide: BorderSide(color: kErrorBase)),
                enabledBorder: OutlineInputBorder(
                    borderRadius: BorderRadius.circular(8),
                    borderSide: BorderSide(
                        style: BorderStyle.solid,
                        color: RothkoCache.getTheme!(context) == ThemeMode.light
                            ? kLightNeutralLighten1
                            : kLightNeutralLighten5)),
                focusedBorder: OutlineInputBorder(
                    borderRadius: BorderRadius.circular(8),
                    borderSide: BorderSide(
                        style: BorderStyle.solid,
                        color: RothkoCache.getTheme!(context) == ThemeMode.light
                            ? kLightNeutralLighten1
                            : Colors.red)),
                contentPadding: EdgeInsets.only(bottom: 16.0, left: 16.0),
                fillColor: RothkoCache.getTheme!(context) == ThemeMode.light &&
                        !_labelFocusNode!.hasFocus
                    ? kLightNeutralLighten5
                    : RothkoCache.getTheme!(context) == ThemeMode.light &&
                            _labelFocusNode!.hasFocus &&
                            widget.enabled!
                        ? kLightNeutralLighten4
                        : RothkoCache.getTheme!(context) == ThemeMode.dark &&
                                !_labelFocusNode!.hasFocus
                            ? kDarkNeutralBase
                            : kDarkNeutralLighten1,
                hintText: widget.hintText,
                filled: true,
                // helperText: widget.helperHint,
                helperStyle: TextStyle(
                    fontSize: 10.0,
                    color: kDarkNeutralLighten3,
                    fontFamily: 'Proxima Nova'),
                suffixIcon: Padding(
                  padding: EdgeInsets.only(top: 5.0),
                  child: widget.timeIcon ??
                      Icon(
                        Icons.keyboard_arrow_down,
                        size: 24.0,
                        color: RothkoCache.getTheme!(context) == ThemeMode.light
                            ? kDarkNeutralLighten3
                            : kPrimaryLighten3,
                      ),
                ),
                labelStyle: TextStyle(
                    fontSize: _labelFocusNode!.hasFocus ? 10.0 : 10.0,
                    fontFamily: 'Proxima Nova',
                    color: RothkoCache.getTheme!(context) == ThemeMode.light &&
                            !_labelFocusNode!.hasFocus &&
                            widget.enabled!
                        ? kDarkNeutralBase
                        : RothkoCache.getTheme!(context) == ThemeMode.light &&
                                _labelFocusNode!.hasFocus &&
                                widget.enabled!
                            ? kDarkNeutralLighten3
                            : RothkoCache.getTheme!(context) ==
                                        ThemeMode.dark &&
                                    !_labelFocusNode!.hasFocus &&
                                    widget.enabled!
                                ? kLightNeutralBase
                                : kPrimaryLighten3),
              ),
            ),
            Positioned(
                left: 13,
                top: currentValue.isEmpty ? 17 : 2,
                child: Text(
                  isFocused ? '' : widget.labelText ?? 'Date',
                  style: TextStyle(
                      fontSize: currentValue.isEmpty ? 14 : 10,
                      fontFamily: 'Proxima Nova',
                      color: RothkoCache.getTheme!(context) ==
                                  ThemeMode.light &&
                              !_labelFocusNode!.hasFocus &&
                              widget.enabled!
                          ? kDarkNeutralLighten3
                          : RothkoCache.getTheme!(context) == ThemeMode.light &&
                                  _labelFocusNode!.hasFocus &&
                                  widget.enabled!
                              ? kDarkNeutralLighten3
                              : RothkoCache.getTheme!(context) ==
                                          ThemeMode.dark &&
                                      !_labelFocusNode!.hasFocus &&
                                      widget.enabled!
                                  ? kLightNeutralBase
                                  : kPrimaryLighten3),
                ))
          ],
        ));
  }
}
