import 'package:flutter/material.dart';
import 'package:rothko_mobile/cache.dart';
import 'package:rothko_mobile/rothko.dart';


class SelectDefault extends StatefulWidget {
  final List<String>? options;
  final BuildContext? context;
  final void Function(String?)? onChanged;
  final String? selected;
  DropDownSize? size;
  final String? hintText;
  final Widget? suffixIcon;
  final String? labelText;
  final Color? labelTextColor;
  final String? Function(String?)? validator;
  final AutovalidateMode? autovalidateMode;
  bool? enabled;
  Function()? onTap;
  bool? readonly;
  final double? labelTextSize, width;
  bool? focused;
  final BorderSide? customBorder;

  SelectDefault(
      {@required this.options,
      this.context,
      this.onChanged,
      this.size,
      this.autovalidateMode,
      this.selected,
      this.hintText,
      this.focused = false,
      this.readonly = false,
      this.onTap,
      this.enabled = true,
      this.suffixIcon,
      this.labelText,
      this.labelTextColor,
      this.validator,
      this.labelTextSize,
      this.customBorder,
      this.width});
  @override
  _SelectDefaultState createState() => _SelectDefaultState();
}

class _SelectDefaultState extends State<SelectDefault> {
  FocusNode? _labelFocusNode;
  Color fillColor = kLightNeutralLighten5;

  bool isFocused = false;
  @override
  void initState() {
    super.initState();
    _labelFocusNode = FocusNode();
    requestFocus();
  }

  @override
  void dispose() {
    _labelFocusNode!.dispose();
    super.dispose();
  }

  void requestFocus() {
    if (widget.selected != null) {
      setState(() {
        isFocused = true;
        widget.focused = true;
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      width: MediaQuery.of(context).size.width * 0.9,
      height: widget.size == DropDownSize.Small ? 50 : 80,
      padding: EdgeInsets.zero,
      child: Stack(
        children: [
          DropdownButtonFormField(
            isDense: true,
            autovalidateMode: widget.autovalidateMode,
            isExpanded: true,
            validator: (String? val) {
              return widget.validator?.call(val);
            },
            style: TextStyle(
                // overflow: TextOverflow.ellipsis,
                ),
            items: widget.options!.map((String f) {
              return DropdownMenuItem(
                onTap: widget.onTap,
                child: Text(
                  '$f',
                  maxLines: null,
                  style: TextStyle(
                      // overflow: TextOverflow.ellipsis,
                      color: widget.enabled! &&
                              RothkoCache.getTheme!(context) == ThemeMode.light
                          ? kDarkNeutralDarken4
                          : !widget.enabled! &&
                                  RothkoCache.getTheme!(context) ==
                                      ThemeMode.light
                              ? kDarkNeutralLighten3
                              : kLightNeutralLighten5,
                      fontSize: widget.labelTextSize ?? 14),
                ),
                value: f,
              );
            }).toList(),
            onChanged: widget.enabled! && widget.readonly == false
                ? widget.onChanged
                : null,
            value: widget.selected,
            onTap: () {
              setState(() {
                isFocused = true;

                widget.focused = true;
              });
            },
            focusNode: _labelFocusNode,
            decoration: InputDecoration(
                suffixIconConstraints: widget.size == DropDownSize.Small
                    ? BoxConstraints(maxHeight: 10)
                    : BoxConstraints(maxHeight: 16.0),
                enabled: widget.enabled!,
                filled: true,
                fillColor: widget.focused! &&
                        RothkoCache.getTheme!(context) == ThemeMode.light
                    ? kLightNeutralLighten4
                    : !widget.focused! &&
                            RothkoCache.getTheme!(context) == ThemeMode.light
                        ? kLightNeutralLighten5
                        : kDarkNeutralBase,
                hintText: widget.hintText,
                border: OutlineInputBorder(
                    borderRadius: BorderRadius.circular(8),
                    borderSide: widget.customBorder ??
                        BorderSide(
                            color: RothkoCache.getTheme!(context) ==
                                    ThemeMode.light
                                ? kLightNeutralLighten1
                                : kDarkNeutralLighten2)),
                errorStyle: TextStyle(color: kErrorBase),
                errorBorder: OutlineInputBorder(
                    borderRadius: BorderRadius.circular(8),
                    borderSide: BorderSide(color: kErrorBase)),
                enabledBorder: OutlineInputBorder(
                    borderRadius: BorderRadius.circular(8),
                    borderSide: widget.customBorder ??
                        BorderSide(
                            style: BorderStyle.solid,
                            color: RothkoCache.getTheme!(context) ==
                                    ThemeMode.light
                                ? kLightNeutralLighten1
                                : kLightNeutralLighten5)),
                focusedBorder: OutlineInputBorder(
                    borderRadius: BorderRadius.circular(8),
                    borderSide: widget.customBorder ??
                        BorderSide(
                            style: BorderStyle.solid,
                            color:
                                RothkoCache.getTheme!(context) == ThemeMode.light
                                    ? kLightNeutralLighten1
                                    : Colors.red)),
                contentPadding:
                    const EdgeInsets.symmetric(vertical: 17.0, horizontal: 13.0),
                hintStyle: TextStyle(
                    color: RothkoCache.getTheme!(context) == ThemeMode.light && !_labelFocusNode!.hasFocus && widget.enabled!
                        ? kDarkNeutralLighten3
                        : RothkoCache.getTheme!(context) == ThemeMode.light && _labelFocusNode!.hasFocus && widget.enabled!
                            ? kDarkNeutralLighten3
                            : RothkoCache.getTheme!(context) == ThemeMode.dark && !_labelFocusNode!.hasFocus && widget.enabled!
                                ? kLightNeutralBase
                                : kPrimaryLighten3,
                    fontFamily: 'Proxima Nova',
                    fontSize: 16,
                    fontWeight: FontWeight.w400),
                labelStyle: TextStyle(
                  fontFamily: 'Proxima Nova',
                  fontSize: 16,
                  fontWeight: FontWeight.w400,
                  color: widget.labelTextColor,
                )),
            iconSize: widget.size == DropDownSize.Small ? 14 : 16,
            icon: widget.suffixIcon,
          ),
          Positioned(
              left: 13,
              top: isFocused ? 7 : 18,
              child: Text(
                widget.size == DropDownSize.Small && isFocused
                    ? ''
                    : widget.labelText!,
                style: TextStyle(
                    fontSize: isFocused ? 10 : 14,
                    fontFamily: 'Proxima Nova',
                    color: RothkoCache.getTheme!(context) == ThemeMode.light &&
                            !_labelFocusNode!.hasFocus &&
                            widget.enabled!
                        ? kDarkNeutralLighten3
                        : RothkoCache.getTheme!(context) == ThemeMode.light &&
                                _labelFocusNode!.hasFocus &&
                                widget.enabled!
                            ? kDarkNeutralLighten3
                            : RothkoCache.getTheme!(context) ==
                                        ThemeMode.dark &&
                                    !_labelFocusNode!.hasFocus &&
                                    widget.enabled!
                                ? kLightNeutralBase
                                : kPrimaryLighten3),
              ))
        ],
      ),
    );
  }
}
