import 'package:flutter/material.dart';
import 'package:rothko_mobile/cache.dart';
import 'package:rothko_mobile/rothko_system/utilities/colors.dart';

class HintDefault extends StatefulWidget {
  final List<String>? options;
  final BuildContext? context;
  final void Function(String?)? onChanged;
  final String? selected;
  final String? hintText;
  final Widget? suffixIcon;
  final Widget? prefix;
  final String? labelText;
  final Color? labelTextColor;
  final String? Function(String?)? validator;
  bool? enabled;
  bool? readonly;
  final double? labelTextSize;
  AutovalidateMode? autovalidateMode;
  bool? focused;
  final BorderSide? customBorder;

  HintDefault(
      {@required this.options,
      this.context,
      this.onChanged,
      this.selected,
      this.hintText,
      this.focused = false,
      this.readonly = false,
      this.autovalidateMode,
      this.enabled = true,
      this.suffixIcon,
      this.labelText,
      this.labelTextColor,
      this.validator,
      this.labelTextSize,
      this.customBorder,
      this.prefix});
  @override
  _HintDefaultState createState() => _HintDefaultState();
}

class _HintDefaultState extends State<HintDefault> {
  Color fillColor = kLightNeutralLighten5;
  FocusNode? _labelFocusNode;

  bool isFocused = false;

  @override
  void initState() {
    super.initState();
    _labelFocusNode = FocusNode();
    requestFocus();
  }

  @override
  void dispose() {
    _labelFocusNode!.dispose();
    super.dispose();
  }

   void requestFocus() {
    if (widget.selected != null ) {
      setState(() {
        isFocused = true;
        widget.focused = true;
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return Column(
      mainAxisAlignment: MainAxisAlignment.center,
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Container(
          width: 320,
          height: 60,
          decoration: BoxDecoration(
            color: widget.focused! &&
                    RothkoCache.getTheme!(context) == ThemeMode.light
                ? kLightNeutralLighten4
                : !widget.focused! &&
                        RothkoCache.getTheme!(context) == ThemeMode.light
                    ? kLightNeutralDarken1
                    : kDarkNeutralLighten2,
            border: Border.all(
              style: BorderStyle.solid,
              color: kLightNeutralLighten1,
            ),
            borderRadius: BorderRadius.circular(8),
          ),
          child: Row(
            children: [
              SizedBox(
                width: 5,
              ),
              widget.prefix ??
                  Icon(
                    Icons.location_on_outlined,
                    color: RothkoCache.getTheme!(context) == ThemeMode.light
                        ? kDarkNeutralLighten3
                        : kPrimaryLighten3,
                  ),
              Container(
                width: 280,
                height: 50,
                child: Stack(
                  children: [
                    DropdownButtonFormField(
                      autovalidateMode: widget.autovalidateMode,
                      validator: widget.validator,
                      items: widget.options!.map((String f) {
                        return DropdownMenuItem(
                          child: Text(
                            '$f',
                            style: TextStyle(
                                color: widget.enabled! &&
                                        RothkoCache.getTheme!(context) ==
                                            ThemeMode.light
                                    ? kDarkNeutralDarken4
                                    : !widget.enabled! &&
                                            RothkoCache.getTheme!(context) ==
                                                ThemeMode.light
                                        ? kDarkNeutralLighten3
                                        : kLightNeutralLighten5,
                                fontSize: widget.labelTextSize ?? 14),
                          ),
                          value: f,
                        );
                      }).toList(),
                      onChanged: widget.enabled! && widget.readonly == false
                          ? widget.onChanged
                          : null,
                      value: widget.selected,
                      onTap: () {
                        setState(() {
                          isFocused = true;
                          widget.focused = true;
                        });
                      },
                      decoration: InputDecoration(
                          enabled: widget.enabled!,
                          filled: true,
                          fillColor: widget.focused! &&
                                  RothkoCache.getTheme!(context) ==
                                      ThemeMode.light
                              ? kLightNeutralLighten4
                              : !widget.focused! &&
                                      RothkoCache.getTheme!(context) ==
                                          ThemeMode.light
                                  ? kLightNeutralDarken1
                                  : kDarkNeutralLighten2,
                          errorStyle: TextStyle(color: kErrorBase),
                          errorBorder: OutlineInputBorder(
                              borderRadius: BorderRadius.circular(8),
                              borderSide: BorderSide(color: kErrorBase)),
                          border: OutlineInputBorder(
                              borderSide: widget.customBorder ??
                                  BorderSide(
                                      style: BorderStyle.solid,
                                      color: kLightNeutralLighten1)),
                          enabledBorder: OutlineInputBorder(
                              borderSide: widget.customBorder ??
                                  BorderSide(
                                      style: BorderStyle.solid,
                                      color: Colors.transparent)),
                          contentPadding: const EdgeInsets.symmetric(
                              vertical: 7.0, horizontal: 13.0),
                          // prefixIconConstraints: BoxConstraints.tight(Size.fromWidth(21)),
                          hintStyle: TextStyle(
                              color: RothkoCache.getTheme!(context) ==
                                          ThemeMode.light &&
                                      !_labelFocusNode!.hasFocus &&
                                      widget.enabled!
                                  ? kDarkNeutralLighten3
                                  : RothkoCache.getTheme!(context) ==
                                              ThemeMode.light &&
                                          _labelFocusNode!.hasFocus &&
                                          widget.enabled!
                                      ? kDarkNeutralLighten3
                                      : RothkoCache.getTheme!(context) ==
                                                  ThemeMode.dark &&
                                              !_labelFocusNode!.hasFocus &&
                                              widget.enabled!
                                          ? kLightNeutralBase
                                          : kPrimaryLighten3,
                              fontFamily: 'Proxima Nova',
                              fontSize: 16,
                              fontWeight: FontWeight.w400),
                          labelStyle: TextStyle(
                            fontFamily: 'Proxima Nova',
                            fontSize: 16,
                            height: _labelFocusNode!.hasFocus ? 2.3 : 1.3,
                            fontWeight: FontWeight.w400,
                            color: widget.labelTextColor,
                          )),
                      iconSize: 19,
                      icon: widget.suffixIcon,
                    ),
                    Positioned(
                        left: 13,
                        top: isFocused ? 4 : 18,
                        child: Text(
                          widget.labelText!,
                          style: TextStyle(
                              fontSize: isFocused ? 10 : 14,
                              fontFamily: 'Proxima Nova',
                              color: RothkoCache.getTheme!(context) ==
                                          ThemeMode.light &&
                                      !_labelFocusNode!.hasFocus &&
                                      widget.enabled!
                                  ? kDarkNeutralLighten3
                                  : RothkoCache.getTheme!(context) ==
                                              ThemeMode.light &&
                                          _labelFocusNode!.hasFocus &&
                                          widget.enabled!
                                      ? kDarkNeutralLighten3
                                      : RothkoCache.getTheme!(context) ==
                                                  ThemeMode.dark &&
                                              !_labelFocusNode!.hasFocus &&
                                              widget.enabled!
                                          ? kLightNeutralBase
                                          : kPrimaryLighten3),
                        ))
                  ],
                ),
              ),
            ],
          ),
        ),
        SizedBox(
          height: 8,
        ),
        Text(
          widget.hintText!,
          style: TextStyle(
              fontFamily: 'Proxima Nova',
              fontSize: 10,
              fontWeight: FontWeight.w400,
              color: kDarkNeutralLighten3),
        )
      ],
    );
  }
}
