import 'package:date_format/date_format.dart';
import 'package:flutter/material.dart';
import 'package:rothko_mobile/rothko.dart';
import 'package:rothko_mobile/rothko_system/snackbar/snackbar.dart';
import 'package:rothko_mobile/rothko_system/utilities/colors.dart';

class MainSnackbar extends StatelessWidget {
  final Widget? child;

  const MainSnackbar({Key? key, this.child}) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      child: child,
    );
  }
}

class SnackbarHelper {
  /// Get a success notification Snackbar.

  static Snackbar defaultSnackbar(
      {@required String? message,
      String? title,
      BuildContext? context,
      EdgeInsets? padding,
      EdgeInsets? margin,
      Duration? duration = const Duration(seconds: 3)}) {
    return Snackbar(
      padding: padding,
      margin: margin,
      onStatusChanged: (status) {},
      snackbarPosition: SnackbarPosition.TOP,
      snackbarStyle: SnackbarStyle.FLOATING,
      title: title,
      message: message,
      trailingButton: GestureDetector(
        onTap: () {},
        child: Text(
          "Close",
          style: TextStyle(
              fontWeight: FontWeight.w700,
              fontFamily: "Proxima Nova",
              color: RothkoCache.getTheme!(context!) == ThemeMode.light
                  ? kPrimaryBase
                  : kPrimaryLighten0),
        ),
      ),
      textColor: RothkoCache.getTheme!(context) == ThemeMode.light
          ? kDarkNeutralBase
          : kPrimaryLighten0,
      backgroundColor: RothkoCache.getTheme!(context) == ThemeMode.light
          ? kLightNeutralBase
          : kDarkNeutralBase,
    );
  }

  /// Get a error notification Snackbar
  static Snackbar withIcon(
      {@required String? message,
      String? title,
      BuildContext? context,
      Widget? trailingButton,
      Color? iconColor,
      Color? textColor,
      Color? bgColor,
      Widget? icon,
      SnackbarPosition? snackbarPosition,
      SnackbarStyle? snackbarStyle,
      Duration duration = const Duration(seconds: 3)}) {
    return Snackbar(
      title: title,
      message: message,
      snackbarPosition: snackbarPosition,
      snackbarStyle: snackbarStyle,
      onStatusChanged: (status) {},
      backgroundColor: bgColor,
      textColor: textColor,
      shouldIconPulse: false,
      padding: EdgeInsets.symmetric(vertical: 25, horizontal: 18),
      margin: EdgeInsets.symmetric(horizontal: 10, vertical: 20),
      borderRadius: 8,
      icon: icon,
      trailingButton: trailingButton,
      fontSize: 12,
      leftBarIndicatorColor: Colors.blue.shade300,
      duration: Duration(seconds: 3),
    );
  }
}
