import 'package:flutter/material.dart';
import 'package:rothko_mobile/cache.dart';
import 'package:rothko_mobile/rothko_system/utilities/colors.dart';

class MobileTabsDynamic extends StatefulWidget {
  final String? tabOne, tabTwo, tabThree;
  final List<Widget>? tabViews;
  final TabController? tabController;
  final List<String>? tab;

  MobileTabsDynamic({
    @required this.tabViews,
    @required this.tab,
    this.tabOne,
    this.tabThree,
    this.tabTwo,
    this.tabController,
  });

  @override
  _MobileTabsDynamicState createState() => _MobileTabsDynamicState();
}

class _MobileTabsDynamicState extends State<MobileTabsDynamic>
    with SingleTickerProviderStateMixin {
  TabController? _tabController;
  int? _currentIndex = 0;
  @override
  void initState() {
    _tabController = new TabController(
        vsync: this, length: widget.tab!.length, initialIndex: _currentIndex!);
    super.initState();
  }

  @override
  void dispose() {
    _tabController!.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: PreferredSize(
        preferredSize: Size(MediaQuery.of(context).size.width, 56),
        child: Padding(
          padding: EdgeInsets.symmetric(horizontal: 8.0),
          child: Container(
            decoration: BoxDecoration(
                color: RothkoCache.getTheme!(context) == ThemeMode.light
                    ? kPrimaryBase
                    : kPrimaryLighten0,
                borderRadius: BorderRadius.circular(8.0)),
            child: TabBar(
              controller: widget.tabController ?? _tabController,
              labelColor: RothkoCache.getTheme!(context) == ThemeMode.light
                  ? kLightNeutralLighten0
                  : kPrimaryBase,
              unselectedLabelColor:
                  RothkoCache.getTheme!(context) == ThemeMode.light
                      ? kPrimaryLighten3
                      : kDarkNeutralLighten4,
              indicatorSize: TabBarIndicatorSize.tab,
              indicatorColor: RothkoCache.getTheme!(context) == ThemeMode.light
                  ? kPrimaryLighten0
                  : kPrimaryBase,

              tabs: List<Widget>.generate(
                widget.tab!.length,
                (int index) {
                  return new Tab(
                    child: Text(
                      widget.tab![index],
                      style: TextStyle(
                          fontFamily: 'Proxima Nova',
                          fontWeight: FontWeight.w700,
                          fontSize: 14.0),
                    ),
                  );
                },
              ),
//
            ),
          ),
        ),
      ),
      body: TabBarView(
        controller: widget.tabController ?? _tabController,
        children: List<Widget>.generate(
          widget.tab!.length,
          (int index) {
            return widget.tabViews![index];
            new Tab(
              child: widget.tabViews![index],
            );
          },
        ),
      ),
    );
  }
}
