import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:rothko_mobile/cache.dart';
import 'package:rothko_mobile/rothko_system/utilities/colors.dart';

class TextAreaClearable extends StatefulWidget {
  final String? label, helperHint;
  ValueChanged<String>? onChanged;
  TextInputType? keyboardType;
  bool enableSuggestions;
  List<TextInputFormatter>? inputFormatters;
  bool? readOnly, enabled;
  final int? maxlength, maxlines;
  String? Function(String?)? validator;
  final AutovalidateMode? autovalidateMode;
  final TextEditingController? textCtrl;

  TextAreaClearable(
      {@required this.label,
      @required this.readOnly,
      @required this.enabled,
      this.helperHint,
      this.maxlength,
      this.keyboardType,
      this.autovalidateMode,
      this.enableSuggestions = false,
      this.onChanged,
      this.validator,
      this.inputFormatters,
      this.maxlines,
      this.textCtrl});
  @override
  _TextAreaClearableState createState() => _TextAreaClearableState();
}

class _TextAreaClearableState extends State<TextAreaClearable> {
  FocusNode? _labelFocusNode;
  Color fillColor = kLightNeutralLighten5;
  TextEditingController _textfieldController = TextEditingController();

  @override
  void initState() {
    super.initState();
    _labelFocusNode = FocusNode();
  }

  @override
  void dispose() {
    _labelFocusNode!.dispose();
    super.dispose();
  }

  void _requestFocus() {
    setState(() {
      FocusScope.of(context).requestFocus(_labelFocusNode);
    });
  }

  @override
  Widget build(BuildContext context) {
    return Ink(
      child: InkWell(
        child: Container(
          constraints: BoxConstraints(maxHeight: 216.0),
          width: MediaQuery.of(context).size.width * 0.9,
          child: Scrollbar(
            child: SingleChildScrollView(
              scrollDirection: Axis.vertical,
              reverse: true,
              child: TextFormField(
                maxLines: widget.maxlines ?? 6,
                autovalidateMode: widget.autovalidateMode,
                enableSuggestions: widget.enableSuggestions,
                inputFormatters: widget.inputFormatters,
                keyboardType: widget.keyboardType,
                onChanged: widget.onChanged,
                maxLength: widget.maxlength,
                validator: widget.validator,
                maxLengthEnforced: false,
                enabled: widget.enabled,
                readOnly: widget.readOnly!,
                controller: widget.textCtrl ?? _textfieldController,
                cursorColor: RothkoCache.getTheme!(context) == ThemeMode.light
                    ? kDarkNeutralBase
                    : kLightNeutralBase,
                cursorHeight: 24.0,
                focusNode: _labelFocusNode,
                onTap: _requestFocus,
                style: TextStyle(
                    height: 1.5,
                    color: RothkoCache.getTheme!(context) == ThemeMode.light &&
                            widget.enabled!
                        ? kDarkNeutralBase
                        : RothkoCache.getTheme!(context) == ThemeMode.light &&
                                !widget.enabled!
                            ? kDarkNeutralLighten4
                            : RothkoCache.getTheme!(context) ==
                                        ThemeMode.dark &&
                                    !widget.enabled!
                                ? kPrimaryLighten3
                                : kLightNeutralBase,
                    fontFamily: 'Proxima Nova',
                    fontSize: 16.0,
                    fontWeight: FontWeight.w400),
                decoration: InputDecoration(
                  errorStyle: TextStyle(color: kErrorBase),
                  errorBorder: UnderlineInputBorder(
                      borderSide: BorderSide(color: kErrorBase)),
                  focusedBorder: UnderlineInputBorder(
                      borderSide: BorderSide(
                          color:
                              RothkoCache.getTheme!(context) == ThemeMode.light
                                  ? kLightNeutralLighten1
                                  : kDarkNeutralLighten2)),
                  fillColor: RothkoCache.getTheme!(context) ==
                              ThemeMode.light &&
                          !_labelFocusNode!.hasFocus
                      ? kLightNeutralLighten5
                      : RothkoCache.getTheme!(context) == ThemeMode.light &&
                              _labelFocusNode!.hasFocus &&
                              widget.enabled!
                          ? kLightNeutralLighten4
                          : RothkoCache.getTheme!(context) == ThemeMode.dark &&
                                  !_labelFocusNode!.hasFocus
                              ? kDarkNeutralBase
                              : kDarkNeutralLighten1,
                  filled: true,
                  helperText: widget.helperHint,
                  alignLabelWithHint: true,
                  helperStyle: TextStyle(
                      fontSize: 10.0,
                      color: kDarkNeutralLighten3,
                      fontFamily: 'Proxima Nova'),
                  suffix: IconButton(
                      onPressed: () {
                        _textfieldController.clear();
                      },
                      icon: Icon(
                        Icons.close,
                        size: 24.0,
                        color: RothkoCache.getTheme!(context) == ThemeMode.light
                            ? kDarkNeutralLighten3
                            : kPrimaryLighten3,
                      )),
                  labelText: widget.label,
                  labelStyle: TextStyle(
                    fontSize: _labelFocusNode!.hasFocus ? 10.0 : 16.0,
                    fontFamily: 'Proxima Nova',
                    color: RothkoCache.getTheme!(context) == ThemeMode.light &&
                            !_labelFocusNode!.hasFocus &&
                            widget.enabled!
                        ? kDarkNeutralBase
                        : RothkoCache.getTheme!(context) == ThemeMode.light &&
                                _labelFocusNode!.hasFocus &&
                                widget.enabled!
                            ? kDarkNeutralLighten3
                            : RothkoCache.getTheme!(context) ==
                                        ThemeMode.dark &&
                                    !_labelFocusNode!.hasFocus &&
                                    widget.enabled!
                                ? kLightNeutralBase
                                : kPrimaryLighten3,
                  ),
                  enabledBorder: UnderlineInputBorder(
                      borderSide: BorderSide(
                          color:
                              RothkoCache.getTheme!(context) == ThemeMode.light
                                  ? kLightNeutralLighten1
                                  : kDarkNeutralLighten2)),
                  disabledBorder: UnderlineInputBorder(
                      borderSide: BorderSide(
                          color:
                              RothkoCache.getTheme!(context) == ThemeMode.light
                                  ? kLightNeutralLighten1
                                  : kDarkNeutralLighten2)),
                  border: UnderlineInputBorder(
                      borderSide: BorderSide(
                          color:
                              RothkoCache.getTheme!(context) == ThemeMode.light
                                  ? kLightNeutralLighten1
                                  : kDarkNeutralLighten2)),
                ),
              ),
            ),
          ),
        ),
        onTap: () {
          setState(() {
            fillColor = RothkoCache.getTheme!(context) == ThemeMode.light
                ? kLightNeutralLighten4
                : kLightNeutralLighten1;
          });
        },
      ),
    );
  }
}
