import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:rothko_mobile/cache.dart';
import 'package:rothko_mobile/rothko_system/utilities/colors.dart';

class TextFieldDefault extends StatefulWidget {
  final String? label, helperHint;
  IconData? suffixIcon;
  Widget? suffixWidget;
  bool? readOnly, enabled;
  final Key? key;
  ValueChanged<String>? onChanged;
  TextInputType? keyboardType;
  AutovalidateMode? autovalidateMode;
  bool enableSuggestions;
  String? Function(String?)? validator;
  List<TextInputFormatter>? inputFormatters;
  final int? maxlength;
  final int? maxLines;
  final String? initialValue;
  final TextEditingController? textCtrl;

  TextCapitalization? textCapitalization;

  TextFieldDefault(
      {@required this.label,
      this.suffixIcon,
      this.suffixWidget,
      @required this.readOnly,
      @required this.enabled,
      this.helperHint,
      this.initialValue,
      this.autovalidateMode,
      this.maxLines = 1,
      this.onChanged,
      this.key,
      this.inputFormatters,
      this.maxlength,
      this.keyboardType,
      this.validator,
      this.enableSuggestions = false,
      this.textCapitalization,
      this.textCtrl});
  @override
  _TextFieldDefaultState createState() => _TextFieldDefaultState();
}

class _TextFieldDefaultState extends State<TextFieldDefault> {
  FocusNode? _labelFocusNode;

  Color fillColor = kLightNeutralLighten5;
  bool isFocused = false;

  var currentValue = '';
  @override
  void initState() {
    super.initState();
    if (widget.textCtrl != null) {
      currentValue = widget.textCtrl!.text;
    }
    if (widget.initialValue != null) {
      currentValue = widget.initialValue!;
    }
    _labelFocusNode = FocusNode();
    _labelFocusNode!.addListener(() {
      if (_labelFocusNode!.hasFocus) {
        setState(() {
          isFocused = true;
        });
        return;
      }
      setState(() {
        isFocused = false;
      });
    });
  }

  @override
  void dispose() {
    _labelFocusNode!.dispose();
    super.dispose();
  }

  void _requestFocus() {
    setState(() {
      FocusScope.of(context).requestFocus(_labelFocusNode);
    });
  }

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      child: Container(
        width: MediaQuery.of(context).size.width * 0.9,
        child: Stack(
          children: [
            TextFormField(
              key: widget.key,
              initialValue: widget.initialValue,
              textCapitalization:
                  widget.textCapitalization ?? TextCapitalization.none,
              maxLength: widget.maxlength,
              enableSuggestions: widget.enableSuggestions,
              inputFormatters: widget.inputFormatters,
              keyboardType: widget.keyboardType,
              onChanged: (val) {
                setState(() {
                  currentValue = val;
                });
                widget.onChanged?.call(val);
              },
              validator: (val) {
                return widget.validator?.call(val);
              },
              autovalidateMode: widget.autovalidateMode,
              maxLengthEnforced: false,
              maxLines: widget.maxLines,
              minLines: 1,
              enabled: widget.enabled,
              readOnly: widget.readOnly!,
              controller: widget.textCtrl,
              cursorColor: RothkoCache.getTheme!(context) == ThemeMode.light
                  ? kDarkNeutralBase
                  : kLightNeutralBase,
              cursorHeight: 24.0,
              focusNode: _labelFocusNode,
              onTap: _requestFocus,
              style: TextStyle(
                  color: RothkoCache.getTheme!(context) == ThemeMode.light &&
                          widget.enabled!
                      ? kDarkNeutralBase
                      : RothkoCache.getTheme!(context) == ThemeMode.light &&
                              !widget.enabled!
                          ? kDarkNeutralLighten4
                          : RothkoCache.getTheme!(context) == ThemeMode.dark &&
                                  !widget.enabled!
                              ? kPrimaryLighten3
                              : kLightNeutralBase,
                  fontFamily: 'Proxima Nova',
                  fontSize: 16.0,
                  fontWeight: FontWeight.w400),
              decoration: InputDecoration(
                errorStyle: TextStyle(color: kErrorBase),
                errorBorder: OutlineInputBorder(
                    borderRadius: BorderRadius.circular(8),
                    borderSide: BorderSide(color: kErrorBase)),
                focusedBorder: OutlineInputBorder(
                    borderRadius: BorderRadius.circular(8),
                    borderSide: BorderSide(
                        color: RothkoCache.getTheme!(context) == ThemeMode.light
                            ? kLightNeutralLighten1
                            : kDarkNeutralLighten2)),
                fillColor: RothkoCache.getTheme!(context) == ThemeMode.light &&
                        !_labelFocusNode!.hasFocus
                    ? kLightNeutralLighten5
                    : RothkoCache.getTheme!(context) == ThemeMode.light &&
                            _labelFocusNode!.hasFocus &&
                            widget.enabled!
                        ? kLightNeutralLighten4
                        : RothkoCache.getTheme!(context) == ThemeMode.dark &&
                                !_labelFocusNode!.hasFocus
                            ? kDarkNeutralBase
                            : kDarkNeutralLighten1,
                filled: true,
                helperText: widget.helperHint,
                helperStyle: TextStyle(
                    fontSize: 10.0,
                    color: kDarkNeutralLighten3,
                    fontFamily: 'Proxima Nova'),
                suffixIcon: GestureDetector(
                  onTap: () => FocusScope.of(context).unfocus(),
                  child: widget.suffixWidget ??
                      Icon(
                        widget.suffixIcon,
                        size: 24.0,
                        color: RothkoCache.getTheme!(context) == ThemeMode.light
                            ? kDarkNeutralLighten3
                            : kPrimaryLighten3,
                      ),
                ),
                labelStyle: TextStyle(
                    fontSize: _labelFocusNode!.hasFocus ? 10.0 : 10.0,
                    fontFamily: 'Proxima Nova',
                    color: RothkoCache.getTheme!(context) == ThemeMode.light &&
                            !_labelFocusNode!.hasFocus &&
                            widget.enabled!
                        ? kDarkNeutralBase
                        : RothkoCache.getTheme!(context) == ThemeMode.light &&
                                _labelFocusNode!.hasFocus &&
                                widget.enabled!
                            ? kDarkNeutralLighten3
                            : RothkoCache.getTheme!(context) ==
                                        ThemeMode.dark &&
                                    !_labelFocusNode!.hasFocus &&
                                    widget.enabled!
                                ? kLightNeutralBase
                                : kPrimaryLighten3),
                enabledBorder: OutlineInputBorder(
                    borderRadius: BorderRadius.circular(8),
                    borderSide: BorderSide(
                        color: RothkoCache.getTheme!(context) == ThemeMode.light
                            ? kLightNeutralLighten1
                            : kDarkNeutralLighten2)),
                disabledBorder: OutlineInputBorder(
                    borderRadius: BorderRadius.circular(8),
                    borderSide: BorderSide(
                        color: RothkoCache.getTheme!(context) == ThemeMode.light
                            ? kLightNeutralLighten1
                            : kDarkNeutralLighten2)),
                border: OutlineInputBorder(
                    borderRadius: BorderRadius.circular(8),
                    borderSide: BorderSide(
                        color: RothkoCache.getTheme!(context) == ThemeMode.light
                            ? kLightNeutralLighten1
                            : kDarkNeutralLighten2)),
              ),
            ),
            Positioned(
                left: 13,
                top: currentValue.isEmpty ? 17 : 3,
                child: Text(
                  isFocused ? '' : widget.label!,
                  style: TextStyle(
                      fontSize: currentValue.isEmpty ? 14 : 10,
                      fontFamily: 'Proxima Nova',
                      color: RothkoCache.getTheme!(context) ==
                                  ThemeMode.light &&
                              !_labelFocusNode!.hasFocus &&
                              widget.enabled!
                          ? kDarkNeutralLighten3
                          : RothkoCache.getTheme!(context) == ThemeMode.light &&
                                  _labelFocusNode!.hasFocus &&
                                  widget.enabled!
                              ? kDarkNeutralLighten3
                              : RothkoCache.getTheme!(context) ==
                                          ThemeMode.dark &&
                                      !_labelFocusNode!.hasFocus &&
                                      widget.enabled!
                                  ? kLightNeutralBase
                                  : kPrimaryLighten3),
                ))
          ],
        ),
      ),
      onTap: () {
        setState(() {
          fillColor = RothkoCache.getTheme!(context) == ThemeMode.light
              ? kLightNeutralLighten4
              : kLightNeutralLighten1;
        });
      },
    );
  }
}
