import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:provider/provider.dart';
import 'package:rothko_mobile/cache.dart';
import 'package:rothko_mobile/rothko_system/utilities/colors.dart';
import 'package:rothko_mobile/widgets/theme/theme_mode_provider.dart';

class TextFieldDense extends StatefulWidget {
  final String? label;
  bool? readOnly, enabled;
  final int? maxlength;
  final int? maxLines;
  ValueChanged<String>? onChanged;
  TextInputType? keyboardType;
  AutovalidateMode? autovalidateMode;
  final String? initialValue;
  bool enableSuggestions;
  String? Function(String?)? validator;
  List<TextInputFormatter>? inputFormatters;

  final TextEditingController? textCtrl;

  TextFieldDense(
      {@required this.label,
      @required this.enabled,
      @required this.readOnly,
      this.onChanged,
      this.inputFormatters,
      this.initialValue,
      this.maxlength,
      this.keyboardType,
      this.maxLines = 1,
      this.autovalidateMode,
      this.validator,
      this.enableSuggestions = false,
      this.textCtrl});
  @override
  _TextFieldDenseState createState() => _TextFieldDenseState();
}

class _TextFieldDenseState extends State<TextFieldDense> {
  FocusNode? _labelFocusNode;
  Color fillColor = kLightNeutralLighten5;
  TextEditingController _textfieldController = TextEditingController();
  bool isFocused = false;

  @override
  void initState() {
    super.initState();
    _labelFocusNode = FocusNode();
    _labelFocusNode!.addListener(() {
      if (_labelFocusNode!.hasFocus) {
        setState(() {
          isFocused = true;
        });
        return;
      }
      setState(() {
        isFocused = false;
      });
    });
  }

  @override
  void dispose() {
    _labelFocusNode!.dispose();
    super.dispose();
  }

  void _requestFocus() {
    setState(() {
      FocusScope.of(context).requestFocus(_labelFocusNode);
    });
  }

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      child: Stack(
        children: [
          Container(
            width: MediaQuery.of(context).size.width * 0.9,
            child: TextFormField(
              initialValue: widget.initialValue,
              maxLength: widget.maxlength,
              autovalidateMode: widget.autovalidateMode,
              enableSuggestions: widget.enableSuggestions,
              inputFormatters: widget.inputFormatters,
              keyboardType: widget.keyboardType,
              onChanged: widget.onChanged,
              validator: widget.validator,
              maxLengthEnforced: false,
              enabled: widget.enabled,
              maxLines: widget.maxLines,
              minLines: 1,
              readOnly: widget.readOnly!,
              controller: widget.textCtrl ?? _textfieldController,
              cursorColor: RothkoCache.getTheme!(context) == ThemeMode.light
                  ? kDarkNeutralBase
                  : kLightNeutralBase,
              cursorHeight: 16.0,
              focusNode: _labelFocusNode,
              onTap: _requestFocus,
              style: TextStyle(
                  color: RothkoCache.getTheme!(context) == ThemeMode.light &&
                          widget.enabled!
                      ? kDarkNeutralBase
                      : RothkoCache.getTheme!(context) == ThemeMode.light &&
                              !widget.enabled!
                          ? kDarkNeutralLighten4
                          : RothkoCache.getTheme!(context) == ThemeMode.dark &&
                                  !widget.enabled!
                              ? kPrimaryLighten3
                              : kLightNeutralBase,
                  fontFamily: 'Proxima Nova',
                  fontSize: 14.0,
                  fontWeight: FontWeight.w400),
              decoration: InputDecoration(
                  errorStyle: TextStyle(color: kErrorBase),
                  errorBorder: OutlineInputBorder(
                      borderRadius: BorderRadius.circular(8),
                      borderSide: BorderSide(color: kErrorBase)),
                  focusedBorder: OutlineInputBorder(
                      borderRadius: BorderRadius.circular(8),
                      borderSide: BorderSide(
                          color: RothkoCache.getTheme!(context) == ThemeMode.light
                              ? kLightNeutralLighten1
                              : kDarkNeutralLighten2)),
                  fillColor: RothkoCache.getTheme!(context) == ThemeMode.light &&
                          !_labelFocusNode!.hasFocus
                      ? kLightNeutralLighten5
                      : RothkoCache.getTheme!(context) == ThemeMode.light &&
                              _labelFocusNode!.hasFocus &&
                              widget.enabled!
                          ? kLightNeutralLighten4
                          : RothkoCache.getTheme!(context) == ThemeMode.dark &&
                                  !_labelFocusNode!.hasFocus
                              ? kDarkNeutralBase
                              : kDarkNeutralLighten1,
                  isDense: true,
                  filled: true,
                  labelStyle: TextStyle(
                      fontSize: _labelFocusNode!.hasFocus ? 10.0 : 14.0,
                      fontFamily: 'Proxima Nova',
                      color: RothkoCache.getTheme!(context) == ThemeMode.light &&
                              !_labelFocusNode!.hasFocus &&
                              widget.enabled!
                          ? kDarkNeutralBase
                          : RothkoCache.getTheme!(context) == ThemeMode.light &&
                                  _labelFocusNode!.hasFocus &&
                                  widget.enabled!
                              ? kDarkNeutralLighten3
                              : RothkoCache.getTheme!(context) == ThemeMode.dark &&
                                      !_labelFocusNode!.hasFocus &&
                                      widget.enabled!
                                  ? kLightNeutralBase
                                  : kPrimaryLighten3),
                  enabledBorder: OutlineInputBorder(
                      borderRadius: BorderRadius.circular(8),
                      borderSide: BorderSide(
                          color:
                              RothkoCache.getTheme!(context) == ThemeMode.light
                                  ? kLightNeutralLighten1
                                  : kDarkNeutralLighten2)),
                  border: OutlineInputBorder(
                      borderRadius: BorderRadius.circular(8),
                      borderSide: BorderSide(color: RothkoCache.getTheme!(context) == ThemeMode.light ? kLightNeutralLighten1 : kDarkNeutralLighten2))),
            ),
          ),
          Positioned(
              left: 13,
              top: widget.textCtrl != null
                  ? widget.textCtrl!.text == ''
                      ? 15
                      : 1
                  : _textfieldController.text == ''
                      ? 17
                      : 3,
              child: Text(
                isFocused ? '' : widget.label!,
                style: TextStyle(
                    fontSize: widget.textCtrl != null
                        ? widget.textCtrl!.text == ''
                            ? 12
                            : 10
                        : _textfieldController.text == ''
                            ? 12
                            : 10,
                    fontFamily: 'Proxima Nova',
                    color: RothkoCache.getTheme!(context) == ThemeMode.light &&
                            !_labelFocusNode!.hasFocus &&
                            widget.enabled!
                        ? kDarkNeutralLighten3
                        : RothkoCache.getTheme!(context) == ThemeMode.light &&
                                _labelFocusNode!.hasFocus &&
                                widget.enabled!
                            ? kDarkNeutralLighten3
                            : RothkoCache.getTheme!(context) ==
                                        ThemeMode.dark &&
                                    !_labelFocusNode!.hasFocus &&
                                    widget.enabled!
                                ? kLightNeutralBase
                                : kPrimaryLighten3),
              ))
        ],
      ),
      onTap: () {
        setState(() {
          fillColor = RothkoCache.getTheme!(context) == ThemeMode.light
              ? kLightNeutralLighten4
              : kLightNeutralLighten1;
        });
      },
    );
  }
}
