import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:rothko_mobile/utilities/breakpoint.dart';
import 'package:rothko_mobile/utilities/iterables.dart';
import 'package:rothko_mobile/widgets/story.dart';

import 'theme/theme_switcher.dart';

class StoryPageWrapper extends StatelessWidget {
  const StoryPageWrapper({
    Key? key,
    this.path,
    this.children = const [],
  }) : super(key: key);

  final String? path;

  final List<Story>? children;

  bool _shouldDisplayDrawer(BuildContext context) =>
      MediaQuery.of(context).breakpoint == Breakpoint.small;

  @override
  Widget build(BuildContext context) {
    final stories = children;
    Story? story;
    try {
      story = stories!.firstWhere(
        (element) {
          return element.path == path;
        },
        // orElse: () => null,
      );
    } catch (e) {}

    final contents = _Contents(
        onTap: (story) => _onStoryTap(context, story),
        current: story,
        children: stories);

    return Scaffold(
      drawer: _shouldDisplayDrawer(context) ? Drawer(child: contents) : null,
      appBar: AppBar(
        title: Text(story?.name ?? 'Rothko Mobile'),
        actions: [ThemeSwitcher()],
      ),
      body: _shouldDisplayDrawer(context)
          ? _buildStory(context, story)
          : Row(
              crossAxisAlignment: CrossAxisAlignment.stretch,
              children: <Widget>[
                Container(
                  width: 200,
                  color: Theme.of(context).cardColor,
                  child: contents,
                ),
                Expanded(child: _buildStory(context, story)),
              ],
            ),
    );
  }

  Widget _buildStory(BuildContext context, Story? story) =>
      Center(child: story ?? const Text('Select Story from Drawer'));

  void _onStoryTap(BuildContext context, Story story) {
    if (_shouldDisplayDrawer(context)) Navigator.of(context).pop();
    Navigator.pushNamed(context, '/stories/${story.path}');
  }
}

class _Contents extends StatelessWidget {
  const _Contents({
    Key? key,
    required this.onTap,
    required this.children,
    this.current,
  }) : super(key: key);

  final List<Story>? children;
  final Story? current;
  final void Function(Story)? onTap;

  @override
  Widget build(BuildContext context) {
    final grouped = children!.groupBy((s) => s.section);
    final sections = grouped.keys
        .where((k) => k!.isNotEmpty)
        .map((k) => _buildSection(k!, grouped[k]!));
    final stories = (grouped[''] ?? []).map(_buildStoryTile);
    return ListView(children: [...sections, ...stories]);
  }

  Widget _buildStoryTile(Story story) => ListTile(
        title: Text(story.name!),
        onTap: () => onTap!(story),
        selected: story == current,
      );

  Widget _buildSection(String title, Iterable<Story> stories) => ExpansionTile(
        title: Text(title),
        initiallyExpanded: stories.contains(current),
        children: stories.map(_buildStoryTile).toList(),
      );
}
